@@ -3,7 +3,7 @@ package POE::Component::WWW::Lipsum;
 use warnings;
 use strict;
 
-our $VERSION = '0.0102';
+our $VERSION = '1.001001'; # VERSION
 
 use POE;
 use base 'POE::Component::NonBlockingWrapper::Base';
@@ -43,6 +43,10 @@ sub _process_request {
 1;
 __END__
 
+=encoding utf8
+
+=for stopwords Ipsum Lorem lipsum
+
 =head1 NAME
 
 POE::Component::WWW::Lipsum - non-blocking wrapper around WWW::Lipsum
@@ -66,7 +70,7 @@ POE::Component::WWW::Lipsum - non-blocking wrapper around WWW::Lipsum
                 args  => {
                     amount => 5,
                     what   => 'paras',
-                    start  => 'no',
+                    start  => 0,
                     html   => 1
                 },
             }
@@ -77,11 +81,11 @@ POE::Component::WWW::Lipsum - non-blocking wrapper around WWW::Lipsum
         my $in_ref = $_[ARG0];
 
         print "$_\n" for @{ $in_ref->{lipsum} };
-        
+
         $poco->shutdown;
     }
 
-Using event based interface is also possible of course.
+    # Using event based interface is also possible of course.
 
 =head1 DESCRIPTION
 
@@ -144,7 +148,7 @@ C<0>.
             args        => {
                 amount => 5,
                 what   => 'paras',
-                start  => 'no',
+                start  => 0,
                 html   => 1,
             },
             _blah       => 'pooh!',
@@ -176,7 +180,7 @@ Takes no arguments. Shuts down the component.
             args        => {
                 amount => 5,
                 what   => 'paras',
-                start  => 'no',
+                start  => 0,
                 html   => 1,
             },
             _blah       => 'pooh!',
@@ -201,7 +205,7 @@ ready. See OUTPUT section for more information.
         args => {
             amount => 5,
             what   => 'paras',
-            start  => 'no',
+            start  => 0,
             html   => 1,
         },
     }
@@ -254,7 +258,7 @@ Takes no arguments. Tells the component to shut itself down.
     };
 
 The event handler set up to handle the event which you've specified in
-the C<event> argument to C<generate()> method/event will recieve input
+the C<event> argument to C<generate()> method/event will receive input
 in the C<$_[ARG0]> in a form of a hashref. The possible keys/value of
 that hashref are as follows:
 
@@ -268,7 +272,7 @@ that hashref are as follows:
     }
 
 The C<lipsum> key will contain an I<arrayref> elements of which will be
-the generated Lorem Ipsum text. Note: if an error occured the C<lipsum>
+the generated Lorem Ipsum text. Note: if an error occurred the C<lipsum>
 key will B<not> be present. See C<error> below.
 
 =head2 C<error>
@@ -291,7 +295,7 @@ the text "Error: ". The bug report has been posted and may be fixed already.
             'amount' => 2,
             'html' => 1,
             'what' => 'paras',
-            'start' => 'no'
+            'start' => 0,
         },
 
 The C<args> key will contain the same hashref that you passed to
@@ -308,52 +312,28 @@ event/method will be present intact in the result.
 
 L<POE>, L<WWW::Lipsum>
 
-=head1 AUTHOR
+head1 REPOSITORY
 
-Zoffix Znet, C<< <zoffix at cpan.org> >>
-(L<http://zoffix.com>, L<http://haslayout.net>)
+Fork this module on GitHub:
+L<https://github.com/zoffixznet/WWW-Lipsum>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-poe-component-www-lipsum at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POE-Component-WWW-Lipsum>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+To report bugs or request features, please use
+L<https://github.com/zoffixznet/WWW-Lipsum/issues>
 
-=head1 SUPPORT
+If you can't access GitHub, you can email your request
+to C<bug-www-lipsum at rt.cpan.org>
 
-You can find documentation for this module with the perldoc command.
+=head1 AUTHOR
 
-    perldoc POE::Component::WWW::Lipsum
+Zoffix Znet <zoffix at cpan.org>
+(L<http://zoffix.com/>, L<http://haslayout.net/>)
 
-You can also look for information at:
+=head1 LICENSE
 
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POE-Component-WWW-Lipsum>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/POE-Component-WWW-Lipsum>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/POE-Component-WWW-Lipsum>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/POE-Component-WWW-Lipsum>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Zoffix Znet, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-
-=cut
+You can use and distribute this module under the same terms as Perl itself.
+See the C<LICENSE> file included in this distribution for complete
+details.
 
+=cut
\ No newline at end of file
